@@ -72,6 +72,7 @@ import com.openexchange.admin.rmi.dataobjects.Quota;
 import com.openexchange.admin.rmi.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.java.Strings;
+import com.openexchange.tools.oxfolder.GABMode;
 
 public abstract class ContextAbstraction extends UserAbstraction {
 
@@ -118,11 +119,6 @@ public abstract class ContextAbstraction extends UserAbstraction {
             return required;
         }
 
-        @Override
-        public void setRequired(final boolean required) {
-            throw new UnsupportedOperationException("setRequired() is not supported for ContextConstants." + this.name() + " enum constant");
-        }
-
     }
 
     private final static char OPT_NAME_DATABASE_ID_SHORT = 'd';
@@ -175,7 +171,10 @@ public abstract class ContextAbstraction extends UserAbstraction {
     protected static final String OPT_NAME_ADMINPASS_DESCRIPTION = "master Admin password";
     protected static final String OPT_NAME_ADMINUSER_DESCRIPTION = "master Admin user name";
 
+    private final static String OPT_GAB_MODE = "gabMode";
+
     protected CLIOption contextQuotaOption = null;
+    protected CLIOption gabModeOption = null;
 
     protected String contextname = null;
 
@@ -218,6 +217,13 @@ public abstract class ContextAbstraction extends UserAbstraction {
         }
     }
 
+    protected void parseAndSetGABMode(final AdminParser parser, final Context ctx) {
+        String value = (String) parser.getOptionValue(gabModeOption);
+        if (null != value) {
+            ctx.setGABMode(GABMode.of(value));
+        }
+    }
+
     protected void parseAndSetExtensions(final AdminParser parser, final Context ctx, final Credentials auth) {
         // We don't check for subclasses being null here because if someone has forgotten
         // to set the options he will directly fix it and thus there no need for the
@@ -269,6 +275,10 @@ public abstract class ContextAbstraction extends UserAbstraction {
     protected void setContextQuotaOption(final AdminParser parser, final boolean required) {
         this.contextQuotaOption = setShortLongOpt(parser, OPT_QUOTA_SHORT, OPT_QUOTA_LONG, OPT_NAME_CONTEXT_QUOTA_DESCRIPTION, true, convertBooleantoTriState(required));
     }
+    
+    protected void seGABModeOption(final AdminParser parser) {
+        this.gabModeOption = setLongOpt(parser, OPT_GAB_MODE, "The optional modus the global address book shall operate on. Currently 'global' and 'individual' are known values.", true, false, true);
+    }
 
     protected void sysoutOutput(Context[] ctxs, AdminParser parser) throws InvalidDataException {
         sysoutOutput(ctxs, false, parser);
