@@ -81,7 +81,7 @@ public class Enable extends ContextAbstraction {
 
             displayEnabledMessage(successtext, null, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, null, e, parser);
         }
 
