@@ -94,7 +94,7 @@ public abstract class DeleteCore extends GroupAbstraction {
 
             displayDeletedMessage(successtext, ctxid, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, ctxid, e, parser);
         }
     }
