@@ -91,7 +91,7 @@ public abstract class DeleteCore extends ResourceAbstraction {
 
             displayDeletedMessage(successtext, ctxid, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, ctxid, e, parser);
         }
     }
