@@ -103,7 +103,7 @@ public abstract class ListCore extends ResourceAbstraction {
             }
 
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, ctxid, e, parser);
         }
     }
