@@ -105,7 +105,7 @@ public abstract class DeleteCore extends UserAbstraction {
 
             displayDeletedMessage(successtext, ctxid, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, ctxid, e, parser);
         }
     }
