@@ -94,12 +94,32 @@ public class GetUserConfigurationSource extends AbstractRmiCLI<Void> {
         new GetUserConfigurationSource().execute(args);
     }
 
+    // ------------------------------------------------------------------------------------------------------------------------------------
+
+    private Integer contextId;
+
+    /**
+     * Prevent instantiation from outside.
+     */
+    private GetUserConfigurationSource() {
+        super();
+    }
+
+    @Override
+    protected boolean isAuthEnabled(RemoteAuthenticator authenticator) throws RemoteException {
+        return contextId == null ? !authenticator.isMasterAuthenticationDisabled() : !authenticator.isContextAuthenticationDisabled();
+    }
+
     /**
      * {@inheritDoc}
      */
     @Override
-    protected void administrativeAuth(String login, String password, CommandLine cmd, RemoteAuthenticator authenticator) {
-        // nothing to do
+    protected void administrativeAuth(String login, String password, CommandLine cmd, RemoteAuthenticator authenticator) throws RemoteException{
+        if (contextId == null) {
+            authenticator.doAuthentication(login, password);
+        } else {
+            authenticator.doAuthentication(login, password, contextId.intValue());
+        }
     }
 
     /**
@@ -141,6 +161,15 @@ public class GetUserConfigurationSource extends AbstractRmiCLI<Void> {
             System.exit(-1);
             return;
         }
+
+        String contextVal = cmd.getOptionValue(OPT_CONTEXT_SHORT);
+        try {
+            contextId = Integer.valueOf(contextVal.trim());
+        } catch (NumberFormatException e) {
+            System.err.println("Cannot parse '" + contextVal + "' as a context id");
+            printHelp();
+            System.exit(1);
+        }
     }
 
     /**
@@ -244,8 +273,8 @@ public class GetUserConfigurationSource extends AbstractRmiCLI<Void> {
      * {@inheritDoc}
      */
     @Override
-    protected boolean requiresAdministrativePermission() {
-        return true;
+    protected Boolean requiresAdministrativePermission() {
+        return null;
     }
 
     /**
