@@ -87,7 +87,7 @@ public class UnregisterDatabase extends DatabaseAbstraction {
 
             displayUnregisteredMessage(successtext, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, null, e, parser);
         }
     }
