@@ -82,7 +82,7 @@ public class RegisterServer extends ServerAbstraction {
 
             displayRegisteredMessage(String.valueOf(oxutil.registerServer(srv, auth).getId()), parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, null, e, parser);
         }
     }
