@@ -375,9 +375,9 @@ public class Database extends EnforceableDataObject implements NameAndIdObject {
                     ret.append(ob);
                     ret.append("\n");
                 }
-            } catch (final IllegalArgumentException e) {
+            } catch (IllegalArgumentException e) {
                 ret.append("IllegalArgument\n");
-            } catch (final IllegalAccessException e) {
+            } catch (IllegalAccessException e) {
                 ret.append("IllegalAccessException\n");
             }
         }
@@ -543,9 +543,6 @@ public class Database extends EnforceableDataObject implements NameAndIdObject {
         return urlset;
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#hashCode()
-     */
     @Override
     public int hashCode() {
         final int prime = 31;
@@ -583,9 +580,6 @@ public class Database extends EnforceableDataObject implements NameAndIdObject {
         return result;
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#equals(java.lang.Object)
-     */
     @Override
     public boolean equals(Object obj) {
         if (this == obj) {
