@@ -56,7 +56,7 @@ package com.openexchange.admin.rmi.exceptions;
  * @author d7
  *
  */
-public class NoSuchUserException extends Exception {
+public class NoSuchUserException extends AbstractAdminRmiException {
 
     /**
      *
