@@ -53,7 +53,7 @@ package com.openexchange.admin.rmi.exceptions;
  *
  * @author cutmasta
  */
-public class PoolException extends Exception {
+public class PoolException extends AbstractAdminRmiException {
 
     /**
      * For serialization
