@@ -103,7 +103,19 @@ public class CreateInfostoreTables extends AbstractCreateTableImpl {
       + "`file_mimetype` varchar(255) ,"
       + "`file_md5sum` varchar(32)  ,"
       + "`file_version_comment` text,"
-      + "`meta` BLOB default NULL,"
+      + "`meta` BLOB DEFAULT NULL,"
+      + "`capture_date` int8 DEFAULT NULL,"
+      + "`geolocation` POINT DEFAULT NULL,"
+      + "`width` int8 UNSIGNED DEFAULT NULL,"
+      + "`height` int8 UNSIGNED DEFAULT NULL,"
+      + "`camera_make` VARCHAR(64) DEFAULT NULL,"
+      + "`camera_model` VARCHAR(128) DEFAULT NULL,"
+      + "`camera_iso_speed` int8 UNSIGNED DEFAULT NULL,"
+      + "`camera_aperture` double DEFAULT NULL,"
+      + "`camera_exposure_time` double DEFAULT NULL,"
+      + "`camera_focal_length` double DEFAULT NULL,"
+      + "`media_meta` MEDIUMBLOB DEFAULT NULL,"
+      + "`media_status` VARCHAR(16) DEFAULT NULL,"
       + "PRIMARY KEY (`cid`,`infostore_id`,`version_number`),"
       + "FOREIGN KEY (cid, infostore_id) REFERENCES infostore (cid, id),"
       + "INDEX `md5sumIndex` (`cid`, `file_md5sum`)"
