@@ -49,7 +49,6 @@
 
 package com.openexchange.admin.rmi.impl;
 
-import java.rmi.RemoteException;
 import com.openexchange.admin.rmi.OXAdminCoreInterface;
 import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.pluginsloaded.PluginsLoadedService;
@@ -69,7 +68,7 @@ public class OXAdminCoreImpl implements OXAdminCoreInterface {
     }
 
     @Override
-    public boolean allPluginsLoaded() throws RemoteException {
+    public boolean allPluginsLoaded() {
         PluginsLoadedService service = AdminServiceRegistry.getInstance().getService(PluginsLoadedService.class);
         if (null == service) {
             LOGGER.error("The PluginsLoadedService was not started");
