@@ -178,7 +178,7 @@ public class UserFilestoreDataMover extends FilestoreDataMover {
                     }
                 }
             } catch (OXException e) {
-                throw new StorageException(e);
+                throw StorageException.wrapForRMI(e);
             } catch (SQLException e) {
                 throw new StorageException(e);
             }
@@ -199,12 +199,10 @@ public class UserFilestoreDataMover extends FilestoreDataMover {
             CacheService cacheService = AdminServiceRegistry.getInstance().getService(CacheService.class);
             Cache cache = cacheService.getCache("Filestore");
             cache.clear();
-            Cache qfsCache = cacheService.getCache("QuotaFileStorages");
-            qfsCache.invalidateGroup(Integer.toString(contextId));
             Cache userCache = cacheService.getCache("User");
             userCache.remove(cacheService.newCacheKey(contextId, userId));
         } catch (OXException e) {
-            throw new StorageException(e);
+            throw StorageException.wrapForRMI(e);
         }
     }
 
